import os


def get_data_path():
    resdir = os.path.join(os.path.dirname(__file__))
    return resdir


def fetch_data():
    os.system("rm -rf /tmp/grip_data > /dev/null 2>&1")
    os.system(
        "git clone --depth=1 ssh://git@stash.dyson.global.corp:7999/fjd/grip_data.git /tmp/grip_data"
    )
    os.system("pip3 install /tmp/grip_data")



# from gym.envs.registration import register

# register(
#     id='panda-v0',
#     entry_point='grip.environments:PandaGraspingEnv',
# )

from time import sleep

from . import agent
from . import io
from . import environments
from . import math
from . import motion
from . import perception
from . import robot
from . import app
from . import sensors


# explicitly list imports in __all__
__all__ = [
    "io",
    "perception",
    "environments",
    "robot",
    "agent",
    "sensors",
    "motion",
    "math",
    "app",
]



import os

from ament_index_python.packages import get_package_share_directory
from launch.substitutions import Command, FindExecutable
from launch_ros.actions import Node
from launch_ros.descriptions import ParameterValue

from grip.ros.depth_proc_launch import depth_proc_launch
import pybullet_data as pd


def generate_launch_description():
    rviz_file = os.path.join(
        get_package_share_directory("grip"), "launch", "rviz/view_panda_d415.rviz"
    )

    franka_xacro_file = os.path.join(
        get_package_share_directory("franka_description"),
        "robots",
        "panda_arm.urdf.xacro",
    )

    robot_description = Command(
        [FindExecutable(name="xacro"), " ", franka_xacro_file, " hand:=true"]
    )

    launch_description = depth_proc_launch("hand_camera")

    launch_description.add_entity(
        Node(
            package="robot_state_publisher",
            executable="robot_state_publisher",
            name="robot_state_publisher",
            output="screen",
            parameters=[
                {"robot_description": ParameterValue(robot_description, value_type=str)}
            ],
        )
    )

    launch_description.add_entity(
        Node(
            package="grip",
            executable="ros_arm_example",
            name="ros_arm_example",
            output="screen",
        )
    )

    launch_description.add_entity(
        Node(
            package="rviz2",
            executable="rviz2",
            name="rviz2",
            arguments=["--display-config", rviz_file],
        )
    )

    return launch_description



"""Launch file for the demo."""

from ament_index_python.packages import (
    get_package_share_path,
)
from launch_ros.actions import Node
from launch_ros.substitutions import FindPackageShare
from moveit_configs_utils import MoveItConfigsBuilder

from launch import LaunchDescription
from launch.actions import DeclareLaunchArgument
from launch.substitutions import LaunchConfiguration, PathJoinSubstitution
from grip.ros import depth_proc_launch

from launch_param_builder import ParameterBuilder

_PANDA_MOVEIT_CONFIG_RSC = "moveit_resources_panda_moveit_config"


def _octomap_launch_params(params: ParameterBuilder):
    params.parameter("octomap_frame", "panda_hand")
    params.parameter("octomap_resolution", 0.05)
    params.parameter("max_range", 5.0)
    return params.to_dict()


def generate_launch_description() -> LaunchDescription:
    """Generate launch description."""

    grip_shared_path = get_package_share_path("grip")

    sensor_path = grip_shared_path / "grip_assets/config" / "sensors3d.yaml"

    print("Path is: ", sensor_path)
    moveit_config = (
        MoveItConfigsBuilder("moveit_resources_panda")
        .robot_description(
            file_path=grip_shared_path / "grip_assets/urdf/robots" / "panda.urdf.xacro",
        )
        .robot_description_semantic(file_path="config/panda.srdf")
        .trajectory_execution(file_path="config/gripper_moveit_controllers.yaml")
        .planning_pipelines(
            pipelines=["ompl", "pilz_industrial_motion_planner"],
        )
        .sensors_3d(file_path=sensor_path)
        .to_moveit_configs()
    )

    # Pybullet grip
    grip_node = Node(
        package="grip",
        executable="ros_robot_moveit",
        parameters=[
            moveit_config.robot_description,
            # {"enable_gui": LaunchConfiguration("enable_gui")},
        ],
        output="screen",
    )

    _params_movegroup = ParameterBuilder(_PANDA_MOVEIT_CONFIG_RSC)

    # Start the actual move_group node/action server
    move_group_node = Node(
        package="moveit_ros_move_group",
        executable="move_group",
        output="screen",
        parameters=[moveit_config.to_dict()]
        + [_octomap_launch_params(_params_movegroup)],
    )

    # RViz
    rviz_node = Node(
        package="rviz2",
        executable="rviz2",
        name="rviz2",
        output="log",
        arguments=[
            "-d",
            PathJoinSubstitution(
                [
                    FindPackageShare("grip"),
                    "launch",
                    "rviz/panda_moveit.rviz",
                ],
            ),
        ],
        parameters=[
            moveit_config.robot_description,
            moveit_config.robot_description_semantic,
            moveit_config.robot_description_kinematics,
            moveit_config.planning_pipelines,
            moveit_config.joint_limits,
        ],
    )

    # Static TF
    static_tf_node = Node(
        package="tf2_ros",
        executable="static_transform_publisher",
        name="static_transform_publisher",
        output="log",
        arguments=["0.0", "0.0", "0.0", "0.0", "0.0", "0.0", "world", "panda_link0"],
    )

    # Publish TF
    robot_state_publisher = Node(
        package="robot_state_publisher",
        executable="robot_state_publisher",
        name="robot_state_publisher",
        output="both",
        parameters=[moveit_config.robot_description],
    )

    # ros2_control
    ros2_control_node = Node(
        package="controller_manager",
        executable="ros2_control_node",
        parameters=[
            moveit_config.robot_description,
            get_package_share_path("moveit_resources_panda_moveit_config")
            / "config"
            / "ros2_controllers.yaml",
        ],
        output="screen",
    )

    joint_state_broadcaster_spawner = Node(
        package="controller_manager",
        executable="spawner",
        arguments=[
            "joint_state_broadcaster",
            "--controller-manager",
            "/controller_manager",
        ],
    )

    panda_arm_controller_spawner = Node(
        package="controller_manager",
        executable="spawner",
        arguments=["panda_arm_controller", "-c", "/controller_manager"],
    )

    panda_hand_controller_spawner = Node(
        package="controller_manager",
        executable="spawner",
        arguments=["panda_hand_controller", "-c", "/controller_manager"],
        output="screen",
    )

    launch_description = depth_proc_launch("hand_camera")

    return LaunchDescription(
        [
            grip_node,
            rviz_node,
            static_tf_node,
            robot_state_publisher,
            move_group_node,
            ros2_control_node,
            joint_state_broadcaster_spawner,
            panda_arm_controller_spawner,
            panda_hand_controller_spawner,
            launch_description,
            DeclareLaunchArgument(
                "enable_gui",
                default_value="true",
                description="Whether to start Pybullet GUI",
            ),
        ],
    )



import os

from ament_index_python.packages import get_package_share_directory

import launch_ros.actions
import launch_ros.descriptions

from grip.ros import depth_proc_launch


def generate_launch_description(camera_name="CameraSensor"):
    default_rviz = os.path.join(
        get_package_share_directory("grip"), "launch", "rviz/rgbd_camera_example.rviz"
    )

    # depth processing launch (converts rgb, depth and camera info into point cloud efficiently)
    launch_description = depth_proc_launch(camera_name)

    # example rgbd camera node
    launch_description.add_entity(
        launch_ros.actions.Node(
            package="grip", executable="rgbd_camera_example", name="rgbd_camera_example"
        )
    )

    # rviz
    launch_description.add_entity(
        launch_ros.actions.Node(
            package="rviz2",
            executable="rviz2",
            output="screen",
            arguments=["--display-config", default_rviz],
        )
    )

    return launch_description



import os
import glob
from setuptools import setup, find_packages


package_name = "grip"
share_dir = os.path.join("share", package_name)

### Crawl files
setup_py_dir = os.path.dirname(os.path.realpath(__file__))

need_files = []
script_files = []
datadir = "grip_assets"

hh = setup_py_dir + "/" + datadir
hh2 = setup_py_dir + "/examples"

for root, dirs, files in os.walk(hh):
    for fn in files:
        ext = os.path.splitext(fn)[1][1:]
        if (
            ext
            and ext
            in "yaml index meta data-00000-of-00001 png gif jpg urdf sdf obj txt mtl dae off stl STL xml cfg pt pth".split()
        ):
            fn = root + "/" + fn
            need_files.append(fn[1 + len(hh) :])


setup(
    name=f"{package_name}x",
    version="0.0.14",
    description="Grip is a prototyping toolbox for manipulation research.",
    long_description=open("README.md").read(),
    url="https://github.com/eaa3/grip.git",
    author="Ermano Arruda",
    maintainer="Ermano Arruda",
    maintainer_email="ermano.arruda@gmail.com",
    license="MIT",
    python_requires=">=3.10,<3.13",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.12",
    ],
    tests_require=["pytest"],
    packages=find_packages(exclude=["test", "test.robot", "test.sensors"]),
    package_dir={"": "."},
    package_data={"grip_assets": need_files},
    data_files=[
        (share_dir, ["package.xml"]),
        ("share/ament_index/resource_index/packages", ["resource/" + package_name]),
        (share_dir + "/launch", glob.glob(os.path.join("launch", "*.launch.py"))),
        (share_dir + "/launch/rviz", glob.glob(os.path.join("launch/rviz", "*.rviz"))),
        (
            share_dir + "/grip_assets/urdf/robots",
            glob.glob(os.path.join("grip_assets/urdf/robots", "*")),
        ),
        (
            share_dir + "/grip_assets/config",
            glob.glob(os.path.join("grip_assets/config", "*.yaml")),
        ),
        (
            share_dir,
            glob.glob("*.md"),
        ),
    ],
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "rgbd_camera_example = grip_examples.sensors.ex02_ros_rgbd_camera:main",
            "ros_arm_example = grip_examples.robot.ex04_ros_robot:main",
            "ros_robot_moveit = grip_examples.robot.ex05_ros_robot_moveit:main",
        ],
    },
)



import os

from ament_index_python.packages import get_package_share_directory
from launch import LaunchDescription
from launch.substitutions import Command, FindExecutable
from launch_ros.actions import Node
from launch_ros.descriptions import ParameterValue


def generate_launch_description():
    rviz_file = os.path.join(
        get_package_share_directory("grip"), "launch", "rviz/view_panda_d415.rviz"
    )

    franka_xacro_file = os.path.join(
        get_package_share_directory("panda_panda_d415"), "urdf", "robot.urdf.xacro"
    )
    robot_description = Command([FindExecutable(name="xacro"), " ", franka_xacro_file])

    return LaunchDescription(
        [
            Node(
                package="robot_state_publisher",
                executable="robot_state_publisher",
                name="robot_state_publisher",
                output="screen",
                parameters=[
                    {
                        "robot_description": ParameterValue(
                            robot_description, value_type=str
                        )
                    }
                ],
                arguments=["--log-level", "debug"],
            ),
            Node(
                package="joint_state_publisher_gui",
                executable="joint_state_publisher_gui",
                name="joint_state_publisher_gui",
            ),
            Node(
                package="rviz2",
                executable="rviz2",
                name="rviz2",
                arguments=["--display-config", rviz_file],
            ),
        ]
    )
